%define pypi_name	pyOpenSSL
%define pkg_name	OpenSSL

%bcond_with doc

Name:		python-%{pkg_name}
Version:	20.0.0
Release:	%mkrel 1
Summary:	Python interface to the OpenSSL library
License:	ASL 2.0
Group:		Development/Python
Url:		https://pypi.org/project/pyOpenSSL/
Source:		%{pypi_source}
BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(cryptography)
%if %{with doc}
BuildRequires:  python3dist(sphinx)
%endif

%description
pyOpenSSL is a high-level Python wrapper around a subset of OpenSSL library.

It includes:
* SSL.Connection objects, wrapping the methods of Python's portable sockets;
* callbacks written in Python;
* an extensive error-handling mechanism, mirroring OpenSSL's error codes;
* and much more.

%package -n python3-%{pkg_name}
Summary:	Python 3 wrapper module around the OpenSSL library
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pkg_name}}

%description -n python3-%{pkg_name}
High-level wrapper around a subset of the OpenSSL library, includes among others
 * SSL.Connection objects, wrapping the methods of Python's portable
   sockets
 * Callbacks written in Python 3
 * Extensive error-handling mechanism, mirroring OpenSSL's error codes

%package doc
Summary:	Documentation for python-%{pkg_name}
BuildArch:	noarch

%description doc
Documentation for python-OpenSSL.

%prep
%setup -q -n py%pkg_name-%version

find -name '*.py' | xargs sed -i '1s|^#!python.*|#!%{__python3}|'

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%py3_build

%if %{with doc}
export PYTHONPATH=$(pwd)
sphinx-build doc html
sphinx-build -b man doc man
%endif

%install
%py3_install

%if %{with doc}
%__install -Dm 0644 %{_builddir}/py%{pkg_name}-%{version}/man/pyopenssl.1 %{buildroot}%{_mandir}/man1/pyopenssl.1
%endif

%files -n python3-%{pkg_name}
%{python3_sitelib}/OpenSSL/
%{python3_sitelib}/pyOpenSSL-*.egg-info

%if %{with doc}
%files doc
%doc examples html
%{_mandir}/man1/pyopenssl.1*
%endif


%changelog
* Sun Dec 13 2020 guillomovitch <guillomovitch> 20.0.0-1.mga8
+ Revision: 1656489
- new version 20.0.0

* Thu Mar 05 2020 kekepower <kekepower> 19.1.0-1.mga8
+ Revision: 1554152
- Update to version 19.1.0

* Sun Feb 16 2020 umeabot <umeabot> 19.0.0-2.mga8
+ Revision: 1530738
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 19.0.0-1.mga8
+ Revision: 1437379
- new version 19.0.0
- drop python2 support
- rebuild for python3.8

* Sat Jan 05 2019 wally <wally> 18.0.0-2.mga7
+ Revision: 1349672
- rebuild for python3.7 without docs

* Mon Nov 19 2018 kekepower <kekepower> 18.0.0-1.mga7
+ Revision: 1331641
- Update to version 18.0.0

* Thu Sep 20 2018 umeabot <umeabot> 17.5.0-4.mga7
+ Revision: 1288202
- Mageia 7 Mass Rebuild

* Sat Apr 07 2018 daviddavid <daviddavid> 17.5.0-3.mga7
+ Revision: 1215895
- python2-OpenSSL provides pyOpenSSL

* Thu Apr 05 2018 kekepower <kekepower> 17.5.0-2.mga7
+ Revision: 1215449
- Renamed python-OpenSSL to python2-OpenSSL

* Tue Mar 20 2018 sander85 <sander85> 17.5.0-1.mga7
+ Revision: 1210826
- New version: 17.5.0

* Mon Aug 07 2017 philippem <philippem> 17.2.0-1.mga7
+ Revision: 1138682
- upgrade to 17.2.0

* Sat Aug 05 2017 pterjan <pterjan> 16.0.0-2.mga7
+ Revision: 1135525
- Rebuild for python 3.6

* Mon Apr 11 2016 philippem <philippem> 16.0.0-1.mga6
+ Revision: 1000252
- update to 16.0.0

* Fri Feb 19 2016 umeabot <umeabot> 0.15.1-2.mga6
+ Revision: 970725
- Mageia 6 Mass Rebuild

* Fri Oct 09 2015 daviddavid <daviddavid> 0.15.1-1.mga6
+ Revision: 888063
- new version: 0.15.1
- rebuild for python 3.5

* Sun Mar 08 2015 philippem <philippem> 0.14-1.mga5
+ Revision: 818118
- update to 0.14

* Wed Oct 15 2014 umeabot <umeabot> 0.13.1-9.mga5
+ Revision: 749978
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.13.1-8.mga5
+ Revision: 729247
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.13.1-7.mga5
+ Revision: 687875
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 0.13.1-6.mga5
+ Revision: 629718
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 0.13.1-5.mga5
+ Revision: 628446
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.13.1-4.mga4
+ Revision: 543013
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.13.1-3.mga4
+ Revision: 498077
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 23 2013 philippem <philippem> 0.13.1-2.mga4
+ Revision: 484420
- Python 3 subpackage
- Split documentation off into noarch subpackage
- Change BuildRequires to texlive-dist

* Mon Sep 09 2013 oden <oden> 0.13.1-1.mga4
+ Revision: 476686
- 0.13.1 (fixes CVE-2013-4314)

* Sun Jan 13 2013 umeabot <umeabot> 0.13-2.mga3
+ Revision: 378442
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 blino <blino> 0.13-1.mga3
+ Revision: 337650
- 0.13 (needed for mitmproxy)

* Sun Jun 19 2011 kharec <kharec> 0.12-1.mga2
+ Revision: 109720
- new version 0.12

* Sat Apr 16 2011 ahmad <ahmad> 0.11-1.mga1
+ Revision: 86767
- update to 0.11
- change Url and Source urls to the new upstream web site
- drop explicit python runtime requires, already handled by the rpm build scripts
- move the cleaning of buildroot to %%install instead of %%prep

* Wed Mar 30 2011 ahmad <ahmad> 0.10-5.mga1
+ Revision: 78969
- replace tetex BR with texlive

* Thu Jan 20 2011 erwan <erwan> 0.10-4.mga1
+ Revision: 27425
- imported package python-OpenSSL


* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 0.10-4mdv2011.0
+ Revision: 589930
- rebuild for python 2.7

* Wed Apr 07 2010 Funda Wang <fwang@mandriva.org> 0.10-3mdv2010.1
+ Revision: 532466
- rebuild

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 0.10-2mdv2010.1
+ Revision: 511630
- rebuilt against openssl-0.9.8m

* Fri Jan 08 2010 Emmanuel Andry <eandry@mandriva.org> 0.10-1mdv2010.1
+ Revision: 487797
- New version 0.10

* Sat Sep 19 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.9-1mdv2010.0
+ Revision: 444738
- Updated to 0.9

* Thu Dec 25 2008 Adam Williamson <awilliamson@mandriva.org> 0.8-1mdv2009.1
+ Revision: 318615
- new release 0.8

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 0.7-2mdv2009.1
+ Revision: 318411
- rebuild for new python

* Sun Aug 17 2008 Lev Givon <lev@mandriva.org> 0.7-1mdv2009.0
+ Revision: 272987
- Update to 0.7.
  Include manual.

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 0.6-6mdv2009.0
+ Revision: 225137
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 10 2007 Andreas Hasenack <andreas@mandriva.com> 0.6-5mdv2008.1
+ Revision: 116966
- rebuild for new docdir policy (no version in docdir)
- quiet %%setup

  + Thierry Vignaud <tv@mandriva.org>
    - fix summary-ended-with-dot


* Tue Nov 28 2006 Götz Waschk <waschk@mandriva.org> 0.6-4mdv2007.0
+ Revision: 88147
- Import python-OpenSSL

* Tue Nov 28 2006 Götz Waschk <waschk@mandriva.org> 0.6-4mdv2007.1
- update file list

* Mon Nov 14 2005 Oden Eriksson <oeriksson@mandriva.com> 0.6-3mdk
- rebuilt against openssl-0.9.8a

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.6-2mdk
- Rebuild for new python

* Sat Nov 13 2004 Goetz Waschk <waschk@linux-mandrake.com> 0.6-1mdk
- New release 0.6

* Sun Jun 13 2004 Pascal Terjan <pterjan@mandrake.org> 0.5.1-3mdk
- Fix BuildRequires

* Wed Jun 02 2004 Pascal Terjan <pterjan@mandrake.org> 0.5.1-2mdk
- Respect naming convention
- DIRM

* Wed Apr 21 2004 Pascal Terjan <pterjan@mandrake.org> 0.5.1-1mdk
- First Mandrakelinux version

